==> RobinCar_0.3.0.tar.gz: RobinCar/README.md <==
[![R-CMD-check](https://github.com/mbannick/RobinCar/actions/workflows/R-CMD-check.yaml/badge.svg?branch=main)](https://github.com/mbannick/RobinCar/actions/workflows/R-CMD-check.yaml) [![DOI](https://zenodo.org/badge/506080289.svg)](https://zenodo.org/badge/latestdoi/506080289)


# RobinCar: ROBust estimation and INference for Covariate Adjustment in Randomized clinical trials

## Authors
Ting Ye, Yanyao Yi, Marlena Bannick (maintainer), and Faith Bian

## Documentation

To view documentation about the functions, see the RobinCar website here: https://marlenabannick.com/RobinCar/. You will also find vignettes about how to use the functions.

## Installation

RobinCar is now available on CRAN!

### 1. Install via CRAN

```{}
install.packages("RobinCar")
```

### 2. Install with `devtools`

To get the most recent version in development, you can install the package with `devtools`:
```{bash}
devtools::install_github("mbannick/RobinCar")
```

### 3. Clone repository

Or to download the package, you may clone the repository:
```{bash}
git clone https://github.com/mbannick/RobinCar.git
```

## Publications

Here are publications and preprints that explain the methods in RobinCar:

* [Ting Ye, Jun Shao, Yanyao Yi (2023)](https://doi.org/10.1093/biomet/asad045)
* [Marlena Bannick, Jun Shao, Jingyi Liu, Yu Du, Yanyao Yi, Ting Ye (2024)](https://doi.org/10.48550/arXiv.2306.10213)
* [Ting Ye, Marlena Bannick, Yanyao Yi, Jun Shao (2023)](https://doi.org/10.1080/24754269.2023.2205802)
* [Ting Ye, Jun Shao, Yanyao Yi, Qinyuan Zhao (2023)](https://doi.org/10.1080/01621459.2022.2049278)

==> RobinCar_1.0.0.tar.gz: RobinCar/README.md <==
[![R-CMD-check](https://github.com/mbannick/RobinCar/actions/workflows/R-CMD-check.yaml/badge.svg?branch=main)](https://github.com/mbannick/RobinCar/actions/workflows/R-CMD-check.yaml) [![DOI](https://zenodo.org/badge/506080289.svg)](https://zenodo.org/badge/latestdoi/506080289)


# RobinCar: ROBust estimation and INference for Covariate Adjustment in Randomized clinical trials

## Authors
Ting Ye, Yanyao Yi, Marlena Bannick (maintainer), Yuhan Qian, and Faith Bian

## Documentation

To view documentation about the functions, see the RobinCar website here: https://marlenabannick.com/RobinCar/. You will also find vignettes about how to use the functions.

## Installation

RobinCar is now available on CRAN!

### 1. Install via CRAN

```{}
install.packages("RobinCar")
```

### 2. Install with `devtools`

To get the most recent version in development, you can install the package with `devtools`:
```{bash}
devtools::install_github("mbannick/RobinCar")
```

### 3. Clone repository

Or to download the package, you may clone the repository:
```{bash}
git clone https://github.com/mbannick/RobinCar.git
```

## Publications

Here are publications and preprints that explain the methods in RobinCar:

* [Ting Ye, Jun Shao, Yanyao Yi (2023)](https://doi.org/10.1093/biomet/asad045)
* [Marlena Bannick, Jun Shao, Jingyi Liu, Yu Du, Yanyao Yi, Ting Ye (2024)](https://doi.org/10.1093/biomet/asaf029)
* [Ting Ye, Marlena Bannick, Yanyao Yi, Jun Shao (2023)](https://doi.org/10.1080/24754269.2023.2205802)
* [Ting Ye, Jun Shao, Yanyao Yi, Qinyuan Zhao (2023)](https://doi.org/10.1080/01621459.2022.2049278)
* [Xiaoyu Qiu, Yuhan Qian, Jaehwan Yi, Jinqiu Wang, Yu Du, Yanyao Yi, Ting Ye (2025)](https://arxiv.org/pdf/2408.12541)
